@@ -17,20 +17,24 @@
 from .services.dataproc_metastore import DataprocMetastoreClient
 from .services.dataproc_metastore import DataprocMetastoreAsyncClient
 
+from .types.metastore import AuxiliaryVersionConfig
 from .types.metastore import Backup
 from .types.metastore import CreateBackupRequest
 from .types.metastore import CreateMetadataImportRequest
 from .types.metastore import CreateServiceRequest
 from .types.metastore import DatabaseDumpSpec
 from .types.metastore import DataCatalogConfig
+from .types.metastore import DataplexConfig
 from .types.metastore import DeleteBackupRequest
 from .types.metastore import DeleteServiceRequest
+from .types.metastore import EncryptionConfig
 from .types.metastore import ExportMetadataRequest
 from .types.metastore import GetBackupRequest
 from .types.metastore import GetMetadataImportRequest
 from .types.metastore import GetServiceRequest
 from .types.metastore import HiveMetastoreConfig
 from .types.metastore import KerberosConfig
+from .types.metastore import Lake
 from .types.metastore import ListBackupsRequest
 from .types.metastore import ListBackupsResponse
 from .types.metastore import ListMetadataImportsRequest
@@ -43,6 +47,7 @@ from .types.metastore import MetadataExport
 from .types.metastore import MetadataImport
 from .types.metastore import MetadataIntegration
 from .types.metastore import MetadataManagementActivity
+from .types.metastore import NetworkConfig
 from .types.metastore import OperationMetadata
 from .types.metastore import Restore
 from .types.metastore import RestoreServiceRequest
@@ -53,21 +58,25 @@ from .types.metastore import UpdateServiceRequest
 
 __all__ = (
     "DataprocMetastoreAsyncClient",
+    "AuxiliaryVersionConfig",
     "Backup",
     "CreateBackupRequest",
     "CreateMetadataImportRequest",
     "CreateServiceRequest",
     "DataCatalogConfig",
     "DatabaseDumpSpec",
+    "DataplexConfig",
     "DataprocMetastoreClient",
     "DeleteBackupRequest",
     "DeleteServiceRequest",
+    "EncryptionConfig",
     "ExportMetadataRequest",
     "GetBackupRequest",
     "GetMetadataImportRequest",
     "GetServiceRequest",
     "HiveMetastoreConfig",
     "KerberosConfig",
+    "Lake",
     "ListBackupsRequest",
     "ListBackupsResponse",
     "ListMetadataImportsRequest",
@@ -80,6 +89,7 @@ __all__ = (
     "MetadataImport",
     "MetadataIntegration",
     "MetadataManagementActivity",
+    "NetworkConfig",
     "OperationMetadata",
     "Restore",
     "RestoreServiceRequest",
