@@ -45,12 +45,11 @@ from .client import DataprocMetastoreClient
 
 class DataprocMetastoreAsyncClient:
     """Configures and manages metastore services. Metastore services are
-    fully managed, highly available, auto-scaled, auto-healing,
-    OSS-native deployments of technical metadata management software.
-    Each metastore service exposes a network endpoint through which
-    metadata queries are served. Metadata queries can originate from a
-    variety of sources, including Apache Hive, Apache Presto, and Apache
-    Spark.
+    fully managed, highly available, autoscaled, autohealing, OSS-native
+    deployments of technical metadata management software. Each
+    metastore service exposes a network endpoint through which metadata
+    queries are served. Metadata queries can originate from a variety of
+    sources, including Apache Hive, Apache Presto, and Apache Spark.
 
     The Dataproc Metastore API defines the following resource model:
 
@@ -76,6 +75,8 @@ class DataprocMetastoreAsyncClient:
 
     backup_path = staticmethod(DataprocMetastoreClient.backup_path)
     parse_backup_path = staticmethod(DataprocMetastoreClient.parse_backup_path)
+    lake_path = staticmethod(DataprocMetastoreClient.lake_path)
+    parse_lake_path = staticmethod(DataprocMetastoreClient.parse_lake_path)
     metadata_import_path = staticmethod(DataprocMetastoreClient.metadata_import_path)
     parse_metadata_import_path = staticmethod(
         DataprocMetastoreClient.parse_metadata_import_path
@@ -84,6 +85,8 @@ class DataprocMetastoreAsyncClient:
     parse_network_path = staticmethod(DataprocMetastoreClient.parse_network_path)
     service_path = staticmethod(DataprocMetastoreClient.service_path)
     parse_service_path = staticmethod(DataprocMetastoreClient.parse_service_path)
+    subnetwork_path = staticmethod(DataprocMetastoreClient.subnetwork_path)
+    parse_subnetwork_path = staticmethod(DataprocMetastoreClient.parse_subnetwork_path)
     common_billing_account_path = staticmethod(
         DataprocMetastoreClient.common_billing_account_path
     )
@@ -1054,7 +1057,7 @@ class DataprocMetastoreAsyncClient:
                 which to create a metastore import, in the following
                 form:
 
-                ``projects/{project_number}/locations/{location_id}/services/{service_id}``
+                ``projects/{project_number}/locations/{location_id}/services/{service_id}``.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1399,7 +1402,7 @@ class DataprocMetastoreAsyncClient:
                 Required. The relative resource name of the metastore
                 service to run restore, in the following form:
 
-                ``projects/{project_id}/locations/{location_id}/services/{service_id}``
+                ``projects/{project_id}/locations/{location_id}/services/{service_id}``.
 
                 This corresponds to the ``service`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1408,7 +1411,7 @@ class DataprocMetastoreAsyncClient:
                 Required. The relative resource name of the metastore
                 service backup to restore from, in the following form:
 
-                ``projects/{project_id}/locations/{location_id}/services/{service_id}/backups/{backup_id}``
+                ``projects/{project_id}/locations/{location_id}/services/{service_id}/backups/{backup_id}``.
 
                 This corresponds to the ``backup`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1678,7 +1681,7 @@ class DataprocMetastoreAsyncClient:
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
-        r"""Creates a new Backup in a given project and location.
+        r"""Creates a new backup in a given project and location.
 
         .. code-block:: python
 
@@ -1712,7 +1715,7 @@ class DataprocMetastoreAsyncClient:
                 Required. The relative resource name of the service in
                 which to create a backup of the following form:
 
-                ``projects/{project_number}/locations/{location_id}/services/{service_id}``
+                ``projects/{project_number}/locations/{location_id}/services/{service_id}``.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
